
{% load crispy_forms_tags crispy_forms_gds %}
<div class="govuk-grid-row">
    <div class="govuk-grid-column-full">
        {% error_summary form %}
        <h1 class="govuk-heading-l">{{ submit_title }}</h1>
        <form novalidate
              method="post"
              action="{% url 'custom-feedback-submit' form_id=form_id %}">
            {% crispy form %}
        </form>
    </div>
</div>
