# Generated by Django 4.1.7 on 2023-03-14 12:55

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="Feedback",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "satisfaction",
                    models.CharField(
                        choices=[
                            ("very_dissatisfied", "Very dissatisfied"),
                            ("dissatisfied", "Dissatisfied"),
                            ("neutral", "Neither satisfied or dissatisfied"),
                            ("satisfied", "Satisfied"),
                            ("very_satisfied", "Very satisfied"),
                        ],
                        max_length=30,
                    ),
                ),
                ("comment", models.TextField(blank=True)),
                (
                    "submitter",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                ("submitted_at", models.DateTimeField(auto_now_add=True, null=True)),
            ],
            options={
                "verbose_name": "Feedback Submission",
                "verbose_name_plural": "Feedback Submissions",
            },
        ),
    ]
